@@ -28,32 +28,31 @@ use autodie ':all';
 use namespace::autoclean;
 
 use Test::Routine;
-with 'Test::Dist::Zilla::Build';
-with 'Test::Dist::Zilla::BuiltFiles';
+with 'PluginTester';
 
 use Test::More;
+use Test::Deep qw{ cmp_deeply };
 
-has options => (
-    isa         => 'HashRef',
+sub build_plugin { 'Templates' };
+
+has exp_files => (
     is          => 'ro',
+    isa         => 'HashRef',
     default     => sub { {} },
 );
 
-sub _build_plugins {
+test 'check_files' => sub {
     my ( $self ) = @_;
-    return [
-        'GatherDir',
-        [ 'Templates' => $self->options ],
-    ];
-};
-
-sub _build_message_filter {
-    return sub {
-        map(
-            { ( my $r = $_ ) =~ s{^\[[^\[\]]*\] }{}; $r; }
-            grep( { $_ =~ m{^\[Templates\] } } @_ )
-        );
+    if ( $self->exception ) {
+        plan skip_all => 'exception occurred';
     };
+    plan tests => keys( %{ $self->exp_files } ) + 0;
+    for my $name ( sort( keys( %{ $self->exp_files } ) ) ) {
+        my $expected = $self->exp_files->{ $name };
+        my @actual   = $self->tzil->built_in->file( $name )->slurp( chomp => 1 );
+        cmp_deeply( \@actual, $expected, $name );
+    };
+    done_testing;
 };
 
 1;
